@@ -8,8 +8,9 @@ package Lemonldap::NG::Common::Safe;
 use strict;
 use base qw(Safe);
 use constant SAFEWRAP => ( Safe->can("wrap_code_ref") ? 1 : 0 );
+use Scalar::Util 'weaken';
 
-our $VERSION = '1.2.2_01';
+our $VERSION = 1.4.0;
 
 our $self;    # Safe cannot share a variable declared with my
 
@@ -36,6 +37,7 @@ sub new {
 
     # Store portal object
     $self->{p} = $portal;
+    weaken $self->{p};
 
     return $self;
 }
